@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import functools
+import math
 import os
 import os.path as osp
 import re
@@ -1031,7 +1032,9 @@ class MainWindow(QtWidgets.QMainWindow):
         if shape is None:
             return
         text, flags, group_id = self.labelDialog.popUp(
-            text=shape.label, flags=shape.flags, group_id=shape.group_id,
+            text=shape.label,
+            flags=shape.flags,
+            group_id=shape.group_id,
         )
         if text is None:
             return
@@ -1058,7 +1061,9 @@ class MainWindow(QtWidgets.QMainWindow):
 
     def fileSearchChanged(self):
         self.importDirImages(
-            self.lastOpenDir, pattern=self.fileSearch.text(), load=False,
+            self.lastOpenDir,
+            pattern=self.fileSearch.text(),
+            load=False,
         )
 
     def fileSelectionChanged(self):
@@ -1164,7 +1169,9 @@ class MainWindow(QtWidgets.QMainWindow):
             other_data = shape["other_data"]
 
             shape = Shape(
-                label=label, shape_type=shape_type, group_id=group_id,
+                label=label,
+                shape_type=shape_type,
+                group_id=group_id,
             )
             for x, y in points:
                 shape.addPoint(QtCore.QPointF(x, y))
@@ -1331,7 +1338,12 @@ class MainWindow(QtWidgets.QMainWindow):
         self.zoom_values[self.filename] = (self.zoomMode, value)
 
     def addZoom(self, increment=1.1):
-        self.setZoom(self.zoomWidget.value() * increment)
+        zoom_value = self.zoomWidget.value() * increment
+        if increment > 1:
+            zoom_value = math.ceil(zoom_value)
+        else:
+            zoom_value = math.floor(zoom_value)
+        self.setZoom(zoom_value)
 
     def zoomRequest(self, delta, pos):
         canvas_width_old = self.canvas.width()
@@ -1352,7 +1364,8 @@ class MainWindow(QtWidgets.QMainWindow):
                 self.scrollBars[Qt.Horizontal].value() + x_shift,
             )
             self.setScroll(
-                Qt.Vertical, self.scrollBars[Qt.Vertical].value() + y_shift,
+                Qt.Vertical,
+                self.scrollBars[Qt.Vertical].value() + y_shift,
             )
 
     def setFitWindow(self, value=True):
@@ -1384,11 +1397,11 @@ class MainWindow(QtWidgets.QMainWindow):
         if brightness is not None:
             dialog.slider_brightness.setValue(brightness)
         if contrast is not None:
-            dialog.slider_brightness.setValue(contrast)
+            dialog.slider_contrast.setValue(contrast)
         dialog.exec_()
 
         brightness = dialog.slider_brightness.value()
-        contrast = dialog.slider_brightness.value()
+        contrast = dialog.slider_contrast.value()
         self.brightnessContrast_values[self.filename] = (brightness, contrast)
 
     def togglePolygons(self, value):
@@ -1440,7 +1453,8 @@ class MainWindow(QtWidgets.QMainWindow):
                 return False
             self.imageData = self.labelFile.imageData
             self.imagePath = osp.join(
-                osp.dirname(label_file), self.labelFile.imagePath,
+                osp.dirname(label_file),
+                self.labelFile.imagePath,
             )
             self.otherData = self.labelFile.otherData
         else:
@@ -1514,13 +1528,14 @@ class MainWindow(QtWidgets.QMainWindow):
         if brightness is not None:
             dialog.slider_brightness.setValue(brightness)
         if contrast is not None:
-            dialog.slider_brightness.setValue(contrast)
+            dialog.slider_contrast.setValue(contrast)
         self.brightnessContrast_values[self.filename] = (brightness, contrast)
         if brightness is not None or contrast is not None:
             dialog.onNewValue(None)
         self.paintCanvas()
         self.addRecentFile(self.filename)
         self.toggleActions(True)
+        self.canvas.setFocus()
         self.status(self.tr("Loaded %s") % osp.basename(str(filename)))
         return True
 
