@@ -5,7 +5,10 @@ from ._io import lblsave
 from .image import apply_exif_orientation
 from .image import img_arr_to_b64
 from .image import img_b64_to_arr
+from .image import img_data_to_arr
+from .image import img_data_to_pil
 from .image import img_data_to_png_data
+from .image import img_pil_to_data
 
 from .shape import labelme_shapes_to_label
 from .shape import masks_to_bboxes
@@ -13,11 +16,6 @@ from .shape import polygons_to_mask
 from .shape import shape_to_mask
 from .shape import shapes_to_label
 
-from .draw import draw_instances
-from .draw import draw_label
-from .draw import label_colormap
-from .draw import label2rgb
-
 from .qt import newIcon
 from .qt import newButton
 from .qt import newAction
