@@ -4,14 +4,13 @@ from qtpy import QtWidgets
 
 
 class ZoomWidget(QtWidgets.QSpinBox):
-
     def __init__(self, value=100):
         super(ZoomWidget, self).__init__()
         self.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
-        self.setRange(10, 1000)
-        self.setSuffix(' %')
+        self.setRange(1, 1000)
+        self.setSuffix(" %")
         self.setValue(value)
-        self.setToolTip('Zoom Level')
+        self.setToolTip("Zoom Level")
         self.setStatusTip(self.toolTip())
         self.setAlignment(QtCore.Qt.AlignCenter)
 
